% short description of function
%
% Funktion zur Darstellung des CO2-Gaswechsels eines
% Paprika-Planzenbestandes: G, [g/(m.h)]. 
% Es wurde Modellansatz 2 der nachfolgenden Referenz
% verwendet.
% Ref: Heissner, A.: Der CO2-Gaswechsel von Paprikapflanzen
% in Abhaengigkeit von der Bestrahlungsstaerke, der CO2-
% Konzentration, der Lufttemperatur und dem Dampfdruck-
% saettigungsdefizit der Luft: Messungen und Modell.
% erschien in Gartenbau, 1997.
%
% Syntax:  G = gawepap3(X, IGLOB, A, P0)
%
% Input parameter:
%    X         - Zustandsgroessen des Gewaechshauses
%    IGLOB     - Globalstrahlung, [W/m]
%    A         - Blattflaechenindex, [m/m]
%    P0        - CO2-Gaswechsel pro Blattflche unter Standard-
%                   bedingungen, [g CO2/(dm.h)]
%
% Output parameter:
%    G         - CO2-Gaswechsels eines Paprika-Planzenbestandes
%                   CO2 in [g/(m.h)]
%
% See also: sdef

% Author:   Hartmut Pohlheim
% History:  10.03.97    file created
%           14.03.97    Veraenderung in Berechnung von G22, nur
%                          die BLFL pro Pflanze wird benutzt, dadurch
%                          eine geringere Extinktion
%                       EXT (Extinktionskoeffizient) auf 0.04 verringert


function G = gawepap3(X, IGLOB, A, P0);

   % DDI = X(:,1);
   % TEMI = X(:,2);
   % CI = X(:,3);
   % IGLOB = KLIMA(:,6);
   % A = PLANT(:,1);
   % P0 = PLANT(:,2);

   % Convert input data to necessary units
   BLFL = A * 1e2;      % Conversion from m to dm
   BQ = 0.63;
   I = BQ .* IGLOB;
   IPHOT = 2.24 * I;    % Conversion from W/m to umol/(m*s)
   NPlant = 3;  % Anzahl der Pflanzen pro m

   % Definition of model specific constants
   A0 = 0.7769;
   B0 = 0.002999; B1 = 0.003177; B2 = -0.01372; B3 = 0.1332; B4 = -0.009128;
   C0 = 0.00009192;
   EXT = 0.0400;

   % Definition of other constants or values
   SDI0 = 10;
   SDI = sdef(X(:,1), X(:,2));

   % Calculation of the model
   G22 = A0 * (1 - exp(-B0 * IPHOT .* exp(-EXT * 0.1667 * BLFL/NPlant)) + ...
               1 - exp(-B0 * IPHOT .* exp(-EXT * 0.5000 * BLFL/NPlant)) + ...
               1 - exp(-B0 * IPHOT .* exp(-EXT * 0.8334 * BLFL/NPlant)));
   G23 = 1 - exp(-B1 * X(:,3));
   G24 = X(:,2) + B2 * X(:,2).^2;
   G25 = B3 * X(:,2) + B4 * X(:,2).^2;
   G26 = (1 + C0 * SDI0.^2) ./ (1 + C0 * SDI.^2);
   G2 = (G22 .* G23 .* G24 + G25) .* G26;

   % Conversion from mg in g
   G = G2 .* BLFL * 1e-3;

   % disp(sprintf('G22: %g  G23: %g  G24: %g  G25: %g  G26: %g  G2: %g  G: %g  BLFL: %g' , ...
   %               G22, G23, G24, G25, G26, G2, G, BLFL));

% End of function
