% Gewchshausklimamodell 'klimod03'
% Das Gewchshausklima wird beschrieben durch ein System von drei nichtlinearen DGL 1. Ordnung
% (Bilanzen der Energie, des Wasserdampfes und des CO2)
% Im folgenden werden die Konstanten bzw. Parameter und Variablen des Modells definiert.
% 13.6.1994

% X ist der Vektor Einflugren mit den Komponenten
% X(1)=x1 Dampfdichte, DDI, g/m
% X(2)=x2 Temperatur, TEMI, C
% X(3)=x3 CO2-Konzentration, CI, ppm
% t ist eine skalare Gre und stellt die Zeit dar, s
    

% Inputgren sind:
% TEMB, Temperatur der Bodenoberflche, C
% TEMG, Temperatur der Gewchshaushlle (Innenseite), C
% TEMA, Auentemperatur, C
% FA, Auenluftfeuchte, % r.F.
% CA, Auen-CO2-Konzentration, ppm
% IGLOB, Globalstrahlung, W/m
% U, Windgeschwindigkeit, m/s
% Diese Gren werden zum Vektor KLIMA zusammengefat:
%    TEMB=KLIMA(1)
%    TEMG=KLIMA(2)
%    TEMA=KLIMA(3)
%    FA=KLIMA(4)
%    CA=KLIMA(5)
%    IGLOB=KLIMA(6)
%    U=KLIMA(7)


% Parameter des Pflanzenbestandes  
% Faktor zur Berechnung des Wasserquivalents des Pflanzenbestandes aus der Blattflche, KP, g/m
%    KP=1000
% Blattflchenindex, A, m/m
% Transpiration pro Blattflche unter Standardbedingungen (TEMI=25 C; SDI=10 hPa; I=300 W/m Globalstrahlung), V0, g H2O/(dm.h)
% CO2-Gaswechsel pro Blattflche unter Standardbedingungen (TEMI=25 C; SDI=10 hPa; I=300 W/m PAR), P0, g CO2/(dm.h)
% A, P0 und V0 werden zum Vektor PLANT zusammengefat
%    A=PLANT(1)
%    P0=PLANT(2)
%    V0=PLANT(3)


% Stellgren sind:
% Q, Heizwrmestromdichte, W/m [J/(s.m)]
% LR, Lftungsrate, m/(m.h)
% W, CO2-Begasungsrate, g/(m.h)
% RM, Wassermenge zur Luftbefeuchtung, g/(m.h)
% Die Stellgren werden zum Vektor STELL zusammengefat:
%    Q=STELL(1)
%    LR=STELL(2)
%    W=STELL(3)
%    RM=STELL(4)


% bersicht der Funktionen, Darstellung des/der
% calctemg: Temperatur der Gewchshaushlle (Innenseite) 'calctemg', TEMG, C
% dadr:     Dampfdruckes 'dadr', PDI, Pa
% gawe01:   CO2-Gaswechsels des Planzenbestandes 'gawe01', G, g/(m.h)
% gesabink: Energie-, Wasserdampf- und CO2-Bilanz des Gewchshauses (Gesamtbilanz)
%           fr stationre Bedingungen 'gesabink'
% gewinn:   Biomasse und Gewinn 'gewinn', BIOM, g/(m.h), GEWI, DM/(m.h)
% kliplast: Daten in: KLIMA, PLANT
% kodiwe:   CO2-Austausches des Gewchshauses mit der Umgebung 'kodiwe', LRK, g/(m.h)
% konden:   Kondensation bzw. Verdunstung an der Gewchshaushlle 'konden', K, g/(m.h)
% lube:     Luftbefeuchtung 'lube', R, g/(m.h)
% qboden:   Wrmebertragung am Boden 'qboden', BOQ, W/m
% qduga:    Energieaustausches durch Wrmedurchgang 'qduga', KQ, W/m
% qglob:    Erwrmung durch die Globalstrahlung 'qglob', IGLOBQ, W/m
% qkonden:  Energieaustausches durch Verdunstung oder Kondensation an der Gewchshaushlle 'qkonden', KONQ, W/m
% qluwe:    Energieaustausches durch Luftwechsel 'qluwe', LRQ, W/m
% script01: Wasserdampfdichte, Temperatur, CO2-Konzentration sowie relativer Feuchte
%           und Dampdrucksttigungsdefizit aus der Bilanz 'gesabiko'; 'script01'
% sdadr:    Sttigungsdampfdruckes ber Wasser 'sdadr', PSI, Pa
% sdef:     Dampfdrucksttigungsdefizits 'sdef', SDI, hPa
% trans01:  Transpiration des Pflanzenbestandes 'trans01', V, g/(m.h)
% trpoko:   Transportkoeffizienten fr Wasserdampf 'trpoko', TK, m/h
% wadawe:   Wasserdampfaustausches durch Lften 'wadawe', LRD, g/(m.h)


% Physikalische Konstanten
% Gaskonstante des Wasserdampfes, RWS, J/(g.K)
%    RWS=0.46152
% Spezifische Wrmekapazitt der Luft, CPL, J/(g.K)
%    CPL=1.006
% Spezifische Wrmekapazitt des Wasserdampfes, CPD, J/(g.K)
%    CPD=1.8631
% Spezifische Wrmekapazitt des Wassers, CPW, J/(g.K)
%    CPW=4.1868
% Verdampfungswrme von Wasser bei 20 C, VDW, J/g
%    VDW=2453 
% Verdampfungswrme von Wasser bei 0 C, VDW0, J/g
%    VDW0=2501
% Dichte der trockenen Luft bei 20 C und 760 Torr, DL, g/m
%    DL=1204
% Dichte von CO2 bei 20 C und 760 Torr, DC, g/m
%    DC=1840
% Konstanten der Dampfdruckformel, Sttigungsdampfdruck fr Wasser ber Wasser, PS, Pa
%    A1=-6094.4642
%    A2=21.1249952
%    A3=-0.02724555
%    A4=0.000016853396
%    A5=2.4575506


% Parameter des Gewchshauses: Glasgewchshaus am Standort Grobeeren, BMFT-Projekt des IGZ Grobeeren/Erfurt e.V.
% Transmissionsgrad des Gewchshauses zur Umrechnung der Globalstrahlung
% auf Bestrahlungsstrke (Horizontalkomponente) ber dem Bestand, BQ, -
%    BQ=0.71
% Mittlere Gewchshaushhe, GH, m
%    GH=3
% Verhltnis Oberflche/Grundflche, GF, -
%    GF=1.64
% Wrmedurchgangszahl bei Windstille, KW0, W/(m.K.h)  
%    KW0=3
% Zunahme von KW0 mit der Windgeschwindigkeit, KW1, (W/(m.K.h))/(m/s)
%    KWI=0.2
% Wrmebertragungskoeffizient an der Bodenoberflche, KB, W/(m.K.h)
%    KB=3
% Faktor zur Bercksichtigung der Erwrmung durch die Globalstrahlung, KI, -
%    KI=???
% Maximale Kondensatmenge an der Gewchshaushlle, KSM, g/m
%    KSM=25
% Wirkungsgrad der Luftbefeuchtung, KR, 1/Pa
%    KR=0.0005


