% SCRipt for running multiple GReenHouSe climate optimizations 9
%
% This script performs evolutionary optimizations of the 
% greenhouse system over long time periods.
% For optimization the long time periods are divided into
% smaller parts. This script performs evolutionary optimizations
% for every small time period. The results (states) of one small
% time period are used as starting point for the next small time
% period. Additionally, long result files are written for quick 
% access to computed results.
% Thus, arbitrary long time periods can be optimized using even
% moderate computers.
%
% Syntax:  scrgrhs9
%
% Input parameter:
%    keine
%
% Output parameter:
%    keine
%
% See also: objgrhs4, plotgrh3, recvgrh3, initgrh3, simgrhs4

% Author:   Hartmut Pohlheim
% History:  26.05.97    file created



% Define objective function
   objfun = 'objgrhs4';
   GeaOpt = geaoptset('System.ObjFunFilename', objfun);

   OptVariant = 1;
   
   % Get parameters
   if OptVariant == 1,
      % Get default parameters for real variables (globally oriented)
      GeaOpt = geaoptset(GeaOpt, tbx3real);    % mutation, recombination, variable format
   
      % Define special parameters
      GeaOpt = geaoptset( GeaOpt ...
                         , 'NumberSubpopulation',        4 ...           % Number of subpopulation
                         , 'NumberIndividuals',         [40, 30, 30, 20] ...     % Number of individuals per subpopulation
                         , 'Selection.GenerationGap',   0.6    ...
                        );
      % goptions(24,[1:6]) = [0.1, 0.01, 0.001, 0.1, 0.01, 0.001];    % Mutation range (Radius)
      % goptions(25,[1:6]) = [10, 10, 10, 10, 10, 10];      % Mutation precision

   elseif OptVariant == 2,
      % Get default parameters for real variables (globally oriented)
      GeaOpt = geaoptset(GeaOpt, tbx3real);    % mutation, recombination, variable format
   
      % Define special parameters
      GeaOpt = geaoptset( GeaOpt ...
                         , 'NumberSubpopulation',        1 ...        % Number of subpopulation
                         , 'NumberIndividuals',         [120] ...     % Number of individuals per subpopulation
                         , 'Mutation.Range',            [1e-2] ...    % mutation range
                         , 'Mutation.Precision',        [24] ...      % mutation precision
                        );

   elseif OptVariant == 3,
      % Get default parameters for real variables (globally oriented)
      GeaOpt = geaoptset(GeaOpt, tbx3es1);    % mutation, recombination, variable format, selection
      % goptions(24,[1:3]) = [ 1, 0.1, 0.001];    % Mutation range (Radius)

   end



% Beginn der Simulation in Stunden (gerechnet vom 1.1.)
   HoursperMonth = compgrhs('hours_per_month');
   TSMonth = 8; TSDay = 25; TSHour = 0;
   TStartOffset = sum(HoursperMonth(1:TSMonth-1))+(TSDay-1)*24+TSHour;
   TSimGesamt = 5*24;            % Dauer der gesamten Simulation in Stunden
   TSimTeil   = 6;               % Dauer einer Teilsimulation in Stunden
   
   ResultPath = 'results/';
   TimeString = sprintf('grenhaus_%g_time%02g_%02g_%02g_%02gd%02gh', OptVariant, TSMonth, TSDay, TSHour, fix(TSimGesamt/24), rem(TSimGesamt,24));
   FileNameBase = [ResultPath TimeString '_01'];
   FileSave = [FileNameBase '.sim'];   % Name des Files, in dem die Simulationsergebnisse gespeichert werden

% Define the output options, path and name of result data files
   GeaOpt = geaoptset( GeaOpt ...
                      , 'Output.TextInterval',        1 ...           % Text output every 5 generations
                      ...   
                      , 'Output.SaveTextInterval',     5 ...                     % Text to File every xx generations
                      , 'Output.SaveTextFilename',    [FileNameBase '.txt'] ...  % Filename of result file, absolut or relative path may be included
                      , 'Output.SaveBinDataInterval',  0 ...                     % Binary Data to File every xx generations
                      , 'Output.SaveBinDataFilename', [FileNameBase '.mat'] ...  % Filename of binary file, absolut or relative path may be included
                      , 'Output.StatePlotInterval',    0 ...                       % plot the state plot
                      , 'Output.StatePlotFunction',  'plotgrh4' ...              % Filename of state plot function
                     );

   GeaOpt = geaoptset( GeaOpt ...
                      , 'Output.GrafikInterval',      0 ...          % Grafic results every 10 generations
                      , 'Output.GrafikMethod',        110011 ...      % Grafic method to use
                      , 'Output.GrafikStyle',         664113 ...      % Grafic styles for specified methods
                     );

% termination criteria with their options
   GeaOpt = geaoptset( GeaOpt ...
                         , 'Termination.Method',         [1] ...   % Termination method: use max gen and max time
                         , 'Termination.MaxGenerations', 100   ...   % Terminate after xx generations
                        );

   PrintStep = 1/4;           % Gibt an, wie oft pro Stunde die Simulationsergebnisse ausgegeben werden
   % PRICES = [];
   PRICES = [3, 1, 5e-5];     % Preis fr Gemse: 3 DM/kg; Kohlendioxid: 1 DM/kg; Heizl: 0.00005 = 13.9 DM/GJ
   PlantModel = 3;            % New paprika model: 3

   % Do optimization over whole simulation period
   for xruning = [1],
      Beginn =  0;
      Ende = ceil((TSimGesamt-TSimTeil)/TSimTeil);
      for ilauf = Beginn:Ende,
         TS = (TStartOffset + ilauf * TSimTeil) * 3600;
         TE = TS + TSimTeil * 3600 - 1;
         VLUB = feval(objfun, [], 1, TS, TE);

         % Lookup of climate
         DataKlimaPlant = compgrhs('lookup_klimaplant', TS, TE);

         if ilauf == Beginn, xinit = []; PrintHeader = 1;
         else xinit = xinitnext; PrintHeader = 0; end

         % Define new start population 
         PopInit = initgrh4(sum(GeaOpt.NumberIndividuals), VLUB, PlantModel, TS, TE, DataKlimaPlant, xinit, PRICES);
         % disp(sprintf('%d: %10g   %10g', ilauf, TS/3600/24, TE/3600/24));
         
         % Call main function for optimization
         [xnew, GeaOpt] = geamain2(objfun, GeaOpt, VLUB, PopInit, PlantModel, TS, TE, DataKlimaPlant, xinit, PRICES);

         xinitnext = recvgrh3(objfun, xnew(1,:), PlantModel, TS, TE, DataKlimaPlant, xinit, PRICES, FileSave, PrintStep, PrintHeader);

      end
   end
   

% End of script

