% SIMulation of GReenHouSe climate model 10, s-function
%
% This function implements the modell of the greenhouse climate model.
%
% Syntax:  sys = simgrhs4(t, X, STELL, flag, MODEL, DataKlimaPlant, PRICES)
%
% Input parameters:
%    t         - given time point
%    X         - current state vector, 1 column per individual
%                1 column for every individual
%    STELL     - input vector; 1 column per individual
%                1 column for every individual
%    flag      - as used in s-functions
%    MODEL     - (optional) used model of system
%                if omitted or empty, MODEL = 1 is assumed
%                1: tomato model
%                2: paprika model 1
%                3: paprika model 2
%    DataKlimaPlant - (optional) Matrix containg data for Klima and Plant
%                if omitted or empty, klidata4 is called to get the data
%    PRICES    - (optional) prices
%                if omitted or empty, PRICES = [] is assumed
%    
%
% Output parameters:
%    sys       - Vector containing the new state derivatives
%                1 column for every individual

% Author:   Hartmut Pohlheim
% History:  13.03.97    file created
%           25.06.98    adaptation to Matlab5


function [sys, x0, str, ts] = simgrhs10(t, X, STELL, flag, MODEL, DataKlimaPlant, PRICES)

% Compute population parameters
if abs(flag) == 1
   % convert from 1 column per individual (compatible with sim)
   % to 1 row per individual (as used in this s-function)
   X = X'; STELL = STELL';

   % get number of individuals and variables per individual
   [NIND, Nvar] = size(X);

   % check input parameters and set defaults if missed
   if nargin < 5, MODEL = []; end
   if isempty(MODEL), MODEL = 3; end
   if     MODEL == 1, GAWE_F = 'gawetom1'; TRANS_F = 'trantom1';
   % elseif MODEL == 2, GAWE_F = 'gawepap1'; TRANS_F = 'tranpap1';
   elseif MODEL == 3, GAWE_F = 'gawepap3'; TRANS_F = 'tranpap3';
   else error(sprintf('Unknown value in parameter MODEL (MODEL: %g) !', MODEL))
   end
   if nargin < 6, DataKlimaPlant = []; else end

   if nargin < 7, PRICES = []; end

   % get klima and plant parameters from DataKlimaPlant or data function
   if isempty(DataKlimaPlant),
      [KLIMA, PLANT] = klidata4(t)
   else
      KlimaPlantOne = table1(DataKlimaPlant, t);
      KLIMA = KlimaPlantOne(1:7);
      PLANT = KlimaPlantOne(8:10);
   end
   KLIMA = repmat(KLIMA, [NIND, 1]);
   PLANT = repmat(PLANT, [NIND, 1]);

   % Temperatur der Gewchshaushlle (Innenseite), C; Parameter: TEMI, TEMA, IGLOB, Time
   KLIMA(:,2) = calctemg(X(:,2), KLIMA(:,3), KLIMA(:,6), t);
   
   A = PLANT(:,1); Q = STELL(:,1); W = STELL(:,3);

   GH = 3; DC = 1840; DL = 1204; CPL = 1.006; CPD = 1.8631; CPW = 4.1868; VDW0 = 2501; KP = 1000;
   CG = GH * CPL * DL + A * KP * CPW;

   % Calculation of DampfDruckInnen
   P = konden(X(:,1), X(:,2), KLIMA(:,2));
   % P = P .* (P > 0.0 & X(:,6) < 25.0) + P .* (P < 0.0 & X(:,6) > 0.0);
   P = P .* (P > 0.0) + P .* (P < 0.0 & X(:,6) > 0.0);
   V = feval(TRANS_F, X, KLIMA(:,6), PLANT(:,1), PLANT(:,3));
   R = 0;  % lube(X, STELL(:,4));
   LRD = wadawe(X(:,1),KLIMA(:,3),KLIMA(:,4),STELL(:,2));
   F1=(1 / (GH * 3600)) * (V + R - P - LRD);    % Umrechnung von pro Stunde in pro Sekunde

   % Calculations for TEMperaturInnen
   PQ=qkonden(X(:,1), X(:,2), KLIMA(:,2));
   % PQ = PQ .* (PQ > 0.0 & X(:,6) < 25.0) + PQ .* (PQ < 0.0 & X(:,6) > 0.0);
   PQ = PQ .* (PQ > 0.0) + PQ .* (PQ < 0.0 & X(:,6) > 0.0);
   IGLOBQ = qglob(KLIMA(:,6));
   LRQ = qluwe(X(:,1), X(:,2), KLIMA(:,3), KLIMA(:,4), STELL(:,2));
   KQ = qduga(X(:,2), KLIMA(:,3), KLIMA(:,7));
   BOQ = qboden(X(:,2), KLIMA(:,1));
   F2 = Q - PQ + IGLOBQ - LRQ - KQ - BOQ; 

   % Calculation of CohlendioxidInnen
   G = feval(GAWE_F, X, KLIMA(:,6), PLANT(:,1), PLANT(:,2));
   LRK = kodiwe(X(:,3), KLIMA(:,5), STELL(:,2));
   F3 = (1 / (GH * DC * 1e-6 * 3600)) * (W - G - LRK);    % Umrechnung von pro Stunde in pro Sekunde

   % Calculation of Biomasseproduktion and Gewinn (using Gaswechsel)
   [BIOM, GEWI] = gewinn1(G, Q, W, PRICES);
   BIOM = BIOM / 3600; GEWI = GEWI / 3600;    % Umrechnung von pro Stunde in pro Sekunde

   % Berechnung der Ableitungen der Zustandsgroessen
   sys(:,1) = F1;         % Derivative of DampfDruckInnen
   sys(:,2) = (1 ./ (CG + GH * CPD * X(:,1))) .* (F2 - GH * (VDW0 + CPD * X(:,2)) .* F1);  % Derivative of TEMperaturInnen
   sys(:,3) = F3;         % Derivative of CohlendioxidInnen
   sys(:,4) = BIOM;       % Derivative of Biomasse
   sys(:,5) = GEWI;       % Derivative of Gewinn
   Pkondverd = (P .* (P > 0.0 & X(:,6) < 25.0) + P .* (P < 0.0 & X(:,6) > 0.0));
   sys(:,6) = Pkondverd ./ 3600;    % Derivative of Kondensation/Verdunstung, Feuchtigkeit an Gewaechshausscheibe

   % convert from 1 row per individual to 1 column per individual; for consistency with sim
   sys = sys';

elseif abs(flag) == 0
   sizes = simsizes;

   sizes.NumContStates  = 6;
   sizes.NumDiscStates  = 0;
   sizes.NumOutputs     = 0;
   sizes.NumInputs      = 3;
   sizes.DirFeedthrough = 0;
   sizes.NumSampleTimes = 1;   % at least one sample time is needed

   sys = simsizes(sizes);

   % Setting dummy start conditions
   x0 = [10, 20, 340, 0, 0, 0];

   % str is always an empty matrix
   str = [];

   % initialize the array of sample times
   ts  = [0 0];
   
elseif any(flag == [2, 3, 4, 9]),
   sys = [];
end

% End of function

