% START DATa of greenhouse climate model
%  
% This function implements the initial values for the states of the 
% greenhouse climate model.
%
% Syntax:  ObjVal = startdat(Time, MONTH, MODEL)
%
% Input parameters:
%    Time      - Zeit (in Sekunden seit Beginn des Tages) der Startzeit
%    MONTH     - Monat der Startzeit
%    MODEL     - (optional) verwendetes MODEL  (0: Tomate, 1: Paprika)
%
% Output parameters:
%    START     - Row vector containing the initial values according to input parameters

% Author:  Hartmut Pohlheim
% History: 31.01.95  Datei angelegt
%          31.01.95  erste Daten aus Optimierungen (Paprika) eingetragen
%          10.04.95  Ergebnisse aus Tomatenoptimierung ueber 1h eingetragen
%          20.05.95  Ueberarbeitung

function [START] = startdat(Time, MONTH, MODEL);

   % check input parameter
   MONTHValues = [2,4,6]; MONTHDefault = 2;   % Berechnungsmonat: 2, 4, 6 sind moeglich; 2 ist Standard
   if nargin > 1, if any(MONTH==MONTHValues) == 0, MONTH = MONTHDefault; end, else MONTH = MONTHDefault; end

   if nargin < 3, MODEL = []; end
   if isempty(MODEL), MODEL = 1; end   % MODEL = 1: Tomate, MODEL = [2, 3]: Paprika

   % Zeit-Vektor in Stunden
   Zeit = [ 0:1:24]';

   % DDI, Dampfdruck Innen, g/m
   % TEMI, Temperatur Innen, C
   % CI, Kohlendioxidgehalt Innen, ppm
   % BIOM, Biomasse, g
   % GEWINN, Gewinn, 0.01 DM
   % KOND, Kondensat an der Gewaechshausscheibe Innen, g/m
   if MODEL == 1,
      %  Februar-Daten           DDI  TEMI    CI   BIOM GEWINN   KOND 
      if     MONTH == 2, START=[ 8.1  16.0   352    0.0    0.0    0.0;    %  0 -  1 Uhr
                                 7.8  16.0   350    0.0    0.0    0.0;    %  1 -  2 Uhr 
                                 7.7  16.0   351    0.0    0.0    0.0;    %  2 -  3 Uhr
                                 7.7  16.0   351    0.0    0.0    0.0;    %  3 -  4 Uhr
                                 7.5  16.0   351    0.0    0.0    0.0;    %  4 -  5 Uhr
                                 8.3  16.0   354    0.0    0.0    0.3;    %  5 -  6 Uhr
                                 9.0  16.0   349    0.0    0.0    4.7;    %  6 -  7 Uhr
                                 5.961199 	14.634400 	360.85278 	0.0 	0.0 	14.048388    %  7 -  8 Uhr
                                 6.129032 	16.846145 	360.08803 	0.00 	0.0 	11.628652    %  8 -  9 Uhr
                                 7.056148 	17.428875 	360.38607 	0.0 	0.0 	11.170112    %  9 - 10 Uhr
                                 7.569320 	16.555593 	360.569363 	0.0 	0.0 	21.581307    % 10 - 11 Uhr
                                 11.053578 	17.928402 	360.808260 	0.0 	0.0 	25.000000    % 11 - 12 Uhr
                                 11.479933 	16.184792 	380.979313 	0.0 	0.0 	25.000000    % 12 - 13 Uhr
                                 11.533557 	15.966219 	317.790223 	0.0 	0.0 	25.000000    % 13 - 14 Uhr
                                 11.548960 	15.953500 	294.978420 	0.0 	0.0 	25.000000    % 14 - 15 Uhr
                                 11.319864 	15.945376 	295.452369 	0.0 	0.0 	25.000000    % 15 - 16 Uhr
                                 10.906380 	16.318370 	310.922184 	0.0 	0.0 	25.000000    % 16 - 17 Uhr
                                 9.953709 	15.855899 	330.059385 	0.0 	0.0 	25.000000    % 17 - 18 Uhr
                                 9.256514 	15.371496 	342.524577 	0.0 	0.0 	25.000000    % 18 - 19 Uhr
                                 8.889945 	15.094055 	348.624559 	0.0 	0.0 	25.000000    % 19 - 20 Uhr
                                 7.969948 	15.128407 	360.18934 	0.0 	0.0 	25.000000    % 20 - 21 Uhr
                                 6.736704 	15.121624 	360.61391	0.0 	0.0 	25.000000    % 21 - 22 Uhr
                                 6.218089 	14.947025 	360.11487 	0.0 	0.0 	24.336480    % 22 - 23 Uhr
                                 8.0  16.0   351    0.0    0.0    0.0     % 23 - 24 Uhr
                                 8.1  16.0   352    0.0    0.0    0.0;    % 24 -  1 Uhr
                               ];


      %  April-Daten             DDI  TEMI    CI   BIOM GEWINN   KOND 
      elseif MONTH == 4, START=[ 8.1  16.0   352    0.0    0.0    0.0;    %  0 -  1 Uhr
    	                           7.8  16.0   350    0.0    0.0    0.0;    %  1 -  2 Uhr 
                                 7.7  16.0   351    0.0    0.0    0.0;    %  2 -  3 Uhr
                                 7.7  16.0   351    0.0    0.0    0.0;    %  3 -  4 Uhr
                                 7.5  16.0   351    0.0    0.0    0.0;    %  4 -  5 Uhr
                                 8.3  16.0   354    0.0    0.0    0.3;    %  5 -  6 Uhr
                                 9.0  16.0   349    0.0    0.0    4.7;    %  6 -  7 Uhr
                                14.808901 	19.485511 	259.292875 	0.0    0.0 	25.000000;    %  7 -  8 Uhr
                                16.101605 	20.669086 	795.431910 	0.0    0.0 	25.000000;    %  8 -  9 Uhr
                                19.355196 	23.783127 	881.079180 	0.0    0.0 	25.000000;    %  9 - 10 Uhr
                                24.249352 	27.400876 	784.475461 	0.0    0.0 	25.000000;    % 10 - 11 Uhr
                                24.089742 	27.726430 	914.411757 	0.0    0.0 	25.000000;    % 11 - 12 Uhr
                                24.212766 	27.969628 	976.064944 	0.0    0.0 	25.000000;    % 12 - 13 Uhr
                                23.834198 	27.560252 	971.822918 	0.0    0.0 	25.000000;    % 13 - 14 Uhr
                                22.244642 	26.082533 	810.880838 	0.0    0.0 	25.000000;    % 14 - 15 Uhr
                                10.731238 	17.402701 	369.739313 	0.0    0.0 	19.367350;    % 15 - 16 Uhr
                                10.651292 	16.801614 	308.190046 	0.0    0.0 	25.000000;    % 16 - 17 Uhr
                                12.512246 	16.724243 	561.818718 	0.0    0.0 	25.000000;    % 17 - 18 Uhr
                                11.589663 	15.840899 	313.808589 	0.0    0.0 	25.000000;    % 18 - 19 Uhr
                                10.976393 	15.863290 	355.974735 	0.0    0.0 	25.000000;    % 19 - 20 Uhr
                                12.286868 	15.911158 	379.995392  0.0    0.0  25.000000;    % 20 - 21 Uhr
                                12.288475 	15.914570 	384.263036  0.0    0.0  25.000000;    % 21 - 22 Uhr
                                12.280953 	15.912540 	386.446165  0.0    0.0  25.000000;    % 22 - 23 Uhr
                                 8.0  16.0   351    0.0    0.0    0.0     % 23 - 24 Uhr
                                 8.1  16.0   352    0.0    0.0    0.0;    % 24 -  1 Uhr
                               ];

      %  Juni-Daten              DDI  TEMI    CI   BIOM GEWINN   KOND 
      elseif MONTH == 6, START=[10.0  16.0   335    0.0    0.0   25.0;    %  0 -  1 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  1 -  2 Uhr 
                                10.0  16.0   335    0.0    0.0   25.0;    %  2 -  3 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  3 -  4 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  4 -  5 Uhr
                                15.433477 	18.975615 	596.840818 	0.0    0.0 	25.000000;    %  5 -  6 Uhr
                                17.398290 	21.144504 	850.570911 	0.0    0.0 	24.979387;    %  6 -  7 Uhr
                                22.235841 	25.516496 	1020.06594 	0.0    0.0 	21.427524;    %  7 -  8 Uhr
                                27.384802 	29.362619 	1122.64973 	0.0    0.0 	8.994124;     %  8 -  9 Uhr
                                30.631866 	31.595177 	985.341594 	0.0    0.0 	3.703180;     %  9 - 10 Uhr
                                32.429687 	32.900299 	940.534929 	0.0    0.0 	0.000000;     % 10 - 11 Uhr
                                25.834048 	29.541619 	408.975058 	0.0    0.0 	0.000000;     % 11 - 12 Uhr
                                25.985184 	29.941646 	618.425319 	0.0    0.0 	0.000000;     % 12 - 13 Uhr
                                22.733045 	27.668776 	250.729512 	0.0    0.0 	0.000000;     % 13 - 14 Uhr
                                20.682976 	26.431760 	532.353763 	0.0    0.0 	0.000000;     % 14 - 15 Uhr
                                18.542737 	24.371807 	271.263703 	0.0    0.0 	0.000000;     % 15 - 16 Uhr
                                17.176026 	23.159931 	409.878522 	0.0    0.0 	0.000000;     % 16 - 17 Uhr
                                24.971801 	27.208206 	1035.21713 	0.0    0.0 	0.000000;     % 17 - 18 Uhr
                                21.415997 	24.210954 	572.973637 	0.0    0.0 	5.868052;     % 18 - 19 Uhr
                                17.011978 	20.247459 	449.505637 	0.0    0.0 	14.70097;     % 19 - 20 Uhr
                                12.127646 	15.929197 	348.798911 	0.0    0.0 	11.78230;     % 20 - 21 Uhr
                                12.365684 	15.998399 	359.398165 	0.0    0.0 	15.72468;     % 21 - 22 Uhr
                                12.840143 	15.902856 	402.312109  0.0    0.0  21.69155;     % 22 - 23 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    % 23 - 24 Uhr
                                10.0  16.0   335    0.0    0.0   25.0     % 24 -  1 Uhr
                               ];
      end

   elseif any(MODEL == [2, 3]),
      %  Februar-Daten           DDI  TEMI    CI   BIOM GEWINN   KOND 
      if     MONTH == 2, START=[ 8.1  16.0   352    0.0    0.0    0.0;    %  0 -  1 Uhr
    	                           7.8  16.0   350    0.0    0.0    0.0;    %  1 -  2 Uhr 
                                 7.7  16.0   351    0.0    0.0    0.0;    %  2 -  3 Uhr
                                 7.7  16.0   351    0.0    0.0    0.0;    %  3 -  4 Uhr
                                 7.5  16.0   351    0.0    0.0    0.0;    %  4 -  5 Uhr
                                 8.3  16.0   354    0.0    0.0    0.3;    %  5 -  6 Uhr
                                 9.0  16.0   349    0.0    0.0    4.7;    %  6 -  7 Uhr
                                10.0  16.0   341    0.0    0.0   17.2;    %  7 -  8 Uhr
                                 9.4  16.0   336    0.0    0.0   25.0;    %  8 -  9 Uhr
                                10.0  18.0   335    0.0    0.0   19.3;    %  9 - 10 Uhr
                                10.5  19.6   336    0.0    0.0    9.7;    % 10 - 11 Uhr
                                10.5  20.7   336    0.0    0.0    0.0;    % 11 - 12 Uhr
                                10.6  21.3   337    0.0    0.0    0.0;    % 12 - 13 Uhr
                                10.2  21.0   338    0.0    0.0    0.0;    % 13 - 14 Uhr
                                11.2  21.2   338    0.0    0.0    0.0;    % 14 - 15 Uhr
                                 9.0  18.7   338    0.0    0.0    0.0;    % 15 - 16 Uhr
                                 8.0  16.6   339    0.0    0.0    0.0;    % 16 - 17 Uhr
                                 9.6  16.0   339    0.0    0.0    0.0;    % 17 - 18 Uhr
                                 9.8  16.0   345    0.0    0.0    0.0;    % 18 - 19 Uhr
                                 8.9  16.0   351    0.0    0.0    0.0;    % 19 - 20 Uhr
                                 9.0  16.0   355    0.0    0.0    0.0;    % 20 - 21 Uhr
                                 7.3  16.0   348    0.0    0.0    0.0;    % 21 - 22 Uhr
                                 7.8  16.0   350    0.0    0.0    0.0;    % 22 - 23 Uhr
                                 8.0  16.0   351    0.0    0.0    0.0     % 23 - 24 Uhr
                                 8.1  16.0   352    0.0    0.0    0.0;    % 24 -  1 Uhr
                               ];

      %  April-Daten             DDI  TEMI    CI   BIOM GEWINN   KOND 
      elseif MONTH == 4, START=[ 8.1  16.0   352    0.0    0.0    0.0;    %  0 -  1 Uhr
    	                           7.8  16.0   350    0.0    0.0    0.0;    %  1 -  2 Uhr 
                                 7.7  16.0   351    0.0    0.0    0.0;    %  2 -  3 Uhr
                                 7.7  16.0   351    0.0    0.0    0.0;    %  3 -  4 Uhr
                                 7.5  16.0   351    0.0    0.0    0.0;    %  4 -  5 Uhr
                                 8.3  16.0   354    0.0    0.0    0.3;    %  5 -  6 Uhr
                                 9.0  16.0   349    0.0    0.0    4.7;    %  6 -  7 Uhr
                                10.0  16.0   341    0.0    0.0   17.2;    %  7 -  8 Uhr
                                 9.4  16.0   336    0.0    0.0   25.0;    %  8 -  9 Uhr
                                10.0  18.0   335    0.0    0.0   19.3;    %  9 - 10 Uhr
                                10.5  19.6   336    0.0    0.0    9.7;    % 10 - 11 Uhr
                                10.5  20.7   336    0.0    0.0    0.0;    % 11 - 12 Uhr
                                10.6  21.3   337    0.0    0.0    0.0;    % 12 - 13 Uhr
                                10.2  21.0   338    0.0    0.0    0.0;    % 13 - 14 Uhr
                                 9.7  20.0   338    0.0    0.0    0.0;    % 14 - 15 Uhr
                                 9.0  18.7   338    0.0    0.0    0.0;    % 15 - 16 Uhr
                                 8.0  16.6   339    0.0    0.0    0.0;    % 16 - 17 Uhr
                                 9.6  16.0   339    0.0    0.0    0.0;    % 17 - 18 Uhr
                                 9.8  16.0   345    0.0    0.0    0.0;    % 18 - 19 Uhr
                                 8.9  16.0   351    0.0    0.0    0.0;    % 19 - 20 Uhr
                                 9.0  16.0   355    0.0    0.0    0.0;    % 20 - 21 Uhr
                                 7.3  16.0   348    0.0    0.0    0.0;    % 21 - 22 Uhr
                                 7.8  16.0   350    0.0    0.0    0.0;    % 22 - 23 Uhr
                                 8.0  16.0   351    0.0    0.0    0.0     % 23 - 24 Uhr
                                 8.1  16.0   352    0.0    0.0    0.0;    % 24 -  1 Uhr
                               ];

      %  Juni-Daten              DDI  TEMI    CI   BIOM GEWINN   KOND 
      elseif MONTH == 6, START=[10.0  16.0   335    0.0    0.0   25.0;    %  0 -  1 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  1 -  2 Uhr 
                                10.0  16.0   335    0.0    0.0   25.0;    %  2 -  3 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  3 -  4 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  4 -  5 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  5 -  6 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    %  6 -  7 Uhr
                                10.0  16.0   335    0.0    0.0   18.0;    %  7 -  8 Uhr
                                 9.5  16.0   335    0.0    0.0   24.5;    %  8 -  9 Uhr
                                 9.7  17.7   335    0.0    0.0   16.8;    %  9 - 10 Uhr
                                10.5  19.6   336    0.0    0.0    7.0;    % 10 - 11 Uhr
                                11.0  21.2   336    0.0    0.0    0.0;    % 11 - 12 Uhr
                                10.0  24.0   340    0.0    0.0    0.0;    % 12 - 13 Uhr
                                10.0  24.0   340    0.0    0.0    0.0;    % 13 - 14 Uhr
                                10.0  22.0   340    0.0    0.0    0.0;    % 14 - 15 Uhr
                                10.0  20.0   340    0.0    0.0    0.0;    % 15 - 16 Uhr
                                10.0  18.0   340    0.0    0.0    0.0;    % 16 - 17 Uhr
                                10.0  16.0   340    0.0    0.0    0.0;    % 17 - 18 Uhr
                                10.0  16.0   340    0.0    0.0    0.0;    % 18 - 19 Uhr
                                10.0  16.0   335    0.0    0.0    5.0;    % 19 - 20 Uhr
                                10.0  16.0   335    0.0    0.0   10.0;    % 20 - 21 Uhr
                                10.0  16.0   335    0.0    0.0   15.0;    % 21 - 22 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    % 22 - 23 Uhr
                                10.0  16.0   335    0.0    0.0   25.0     % 23 - 24 Uhr
                                10.0  16.0   335    0.0    0.0   25.0;    % 24 -  1 Uhr
                               ];
      end
   else error(sprintf('No start values for MODEL = %g defined.', MODEL));
   end
   
   % Berechnung des (Startdat)Zeitpunktes durch Umrechnung der Zeit von Sekunden auf Stunden und auf weniger als 24 Uhr
   % Zuweisen der Startdaten fuer diesen Zeitpunkt
   Time = Time ./ 3600;
   START = table1([Zeit, START], Time);
   

% End of function
